@@ -138,6 +138,52 @@ extern "C" {
     }                                                           \
 } while(0)
 
+/**
+ * cut_assert_true:
+ * @expression: the expression to check.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if @expression is TRUE value (not 0 or NULL).
+ *
+ * Since: 0.9
+ */
+#define cut_assert_true(expression, ...) do                     \
+{                                                               \
+    if (expression) {                                           \
+        cut_test_pass();                                        \
+    } else {                                                    \
+        cut_test_fail(FAILURE,                                  \
+                      cut_take_printf("expected: <%s>"          \
+                                      " is TRUE value",         \
+                                      #expression),             \
+                      ## __VA_ARGS__);                          \
+    }                                                           \
+} while(0)
+
+/**
+ * cut_assert_false:
+ * @expression: the expression to check.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if @expression is 0 or NULL.
+ *
+ * Since: 0.9
+ */
+#define cut_assert_false(expression, ...) do                    \
+{                                                               \
+    if (expression) {                                           \
+        cut_test_fail(FAILURE,                                  \
+                      cut_take_printf("expected: <%s>"          \
+                                      " is FALSE/NULL",         \
+                                      #expression),             \
+                      ## __VA_ARGS__);                          \
+    } else {                                                    \
+        cut_test_pass();                                        \
+    }                                                           \
+} while(0)
+
 /**
  * cut_assert_null:
  * @expression: the expression to check.
@@ -325,10 +371,13 @@ extern "C" {
                 const char *diff;                                       \
                                                                         \
                 diff = cut_take_diff(_expected, _actual);               \
-                message = cut_take_printf("%s\n"                        \
-                                          "diff:\n"                     \
-                                          "%s",                         \
-                                          message, diff);               \
+                if (cut_utils_is_interested_diff(diff)) {               \
+                    message = cut_take_printf("%s\n"                    \
+                                              "\n"                      \
+                                              "diff:\n"                 \
+                                              "%s",                     \
+                                              message, diff);           \
+                }                                                       \
             }                                                           \
             cut_test_fail(FAILURE, message, ## __VA_ARGS__);            \
         }                                                               \
@@ -408,7 +457,7 @@ extern "C" {
 /**
  * cut_assert_equal_string_array:
  * @expected: an expected NULL-terminated array of strings.
- * @actual: an actual NULL-terminated array of strings.
+ * @actual: an actual NULL-terminated array of strings that are freed.
  * @...: optional format string, followed by parameters to insert
  * into the format string (as with printf())
  *
@@ -434,6 +483,23 @@ extern "C" {
     }                                                                   \
 } while(0)
 
+/**
+ * cut_assert_equal_string_array_with_free:
+ * @expected: an expected NULL-terminated array of strings.
+ * @actual: an actual NULL-terminated array of strings.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if both @expected and @actual are not NULL and
+ * have same content (strcmp() == 0) strings.
+ *
+ * Since: 0.9
+ */
+#define cut_assert_equal_string_array_with_free(expected, actual, ...)  \
+    cut_assert_equal_string_array(expected,                             \
+                                  cut_take_string_array(actual),        \
+                                  ## __VA_ARGS__);
+
 /**
  * cut_assert_operator:
  * @lhs: a left hand side value.
@@ -521,7 +587,6 @@ extern "C" {
 
 /**
  * cut_assert_errno:
- * @...: the parameters to insert into the format string.
  * @...: optional format string, followed by parameters to insert
  * into the format string (as with printf())
  *
@@ -549,6 +614,34 @@ extern "C" {
     }                                                                   \
 } while(0)
 
+/**
+ * cut_assert_file_exist:
+ * @path: the path to test.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if @path is exist. It may or may not be a regular file.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_file_exist("/tmp");             -> Pass on many environment.
+ * cut_assert_file_exist("/non-existent");    -> Fail
+ * ]|
+ *
+ * Since: 0.9
+ */
+#define cut_assert_file_exist(path, ...) do                             \
+{                                                                       \
+    const char *_path = (path);                                         \
+    if (cut_utils_file_exist(_path)) {                                  \
+        cut_test_pass();                                                \
+    } else {                                                            \
+        cut_test_fail(FAILURE,                                          \
+                      cut_take_printf("expected: <%s> exist", _path),   \
+                      ## __VA_ARGS__);                                  \
+    }                                                                   \
+} while(0)
+
 #ifdef __cplusplus
 }
 #endif
