@@ -19,8 +19,13 @@
 #include "cut-report-factory-builder.h"
 #include "cut-ui-factory-builder.h"
 #include "cut-module-factory.h"
+#include "cut-module-factory-utils.h"
 #include "cut-report.h"
+#include "cut-process.h"
+#include "cut-xml-parser.h"
 #include "cut-verbose-level.h"
+#include "cut-sequence-matcher.h"
+#include "cut-diff.h"
 
 /* enumerations from "cut-public.h" */
 GType
@@ -29,8 +34,10 @@ cut_test_result_status_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
+      { CUT_TEST_RESULT_INVALID, "CUT_TEST_RESULT_INVALID", "invalid" },
       { CUT_TEST_RESULT_SUCCESS, "CUT_TEST_RESULT_SUCCESS", "success" },
       { CUT_TEST_RESULT_NOTIFICATION, "CUT_TEST_RESULT_NOTIFICATION", "notification" },
+      { CUT_TEST_RESULT_OMISSION, "CUT_TEST_RESULT_OMISSION", "omission" },
       { CUT_TEST_RESULT_PENDING, "CUT_TEST_RESULT_PENDING", "pending" },
       { CUT_TEST_RESULT_FAILURE, "CUT_TEST_RESULT_FAILURE", "failure" },
       { CUT_TEST_RESULT_ERROR, "CUT_TEST_RESULT_ERROR", "error" },
@@ -56,25 +63,12 @@ cut_order_get_type (void)
   return etype;
 }
 GType
-cut_report_file_mode_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CUT_REPORT_FILE_OVERWRITE, "CUT_REPORT_FILE_OVERWRITE", "overwrite" },
-      { CUT_REPORT_FILE_APPEND, "CUT_REPORT_FILE_APPEND", "append" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CutReportFileMode", values);
-  }
-  return etype;
-}
-GType
 cut_verbose_level_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
+      { CUT_VERBOSE_LEVEL_INVALID, "CUT_VERBOSE_LEVEL_INVALID", "invalid" },
       { CUT_VERBOSE_LEVEL_SILENT, "CUT_VERBOSE_LEVEL_SILENT", "silent" },
       { CUT_VERBOSE_LEVEL_NORMAL, "CUT_VERBOSE_LEVEL_NORMAL", "normal" },
       { CUT_VERBOSE_LEVEL_VERBOSE, "CUT_VERBOSE_LEVEL_VERBOSE", "verbose" },
@@ -97,6 +91,22 @@ cut_verbose_level_error_get_type (void)
   }
   return etype;
 }
+GType
+cut_sequence_match_operation_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_SEQUENCE_MATCH_OPERATION_EQUAL, "CUT_SEQUENCE_MATCH_OPERATION_EQUAL", "equal" },
+      { CUT_SEQUENCE_MATCH_OPERATION_INSERT, "CUT_SEQUENCE_MATCH_OPERATION_INSERT", "insert" },
+      { CUT_SEQUENCE_MATCH_OPERATION_DELETE, "CUT_SEQUENCE_MATCH_OPERATION_DELETE", "delete" },
+      { CUT_SEQUENCE_MATCH_OPERATION_REPLACE, "CUT_SEQUENCE_MATCH_OPERATION_REPLACE", "replace" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutSequenceMatchOperationType", values);
+  }
+  return etype;
+}
 
 /* Generated data ends here */
 
