@@ -25,6 +25,8 @@
 #include <cutter/cut-value-equal.h>
 #include <cutter/cut-list.h>
 #include <cutter/cut-assertions.h>
+#include <cutter/cut-gpublic.h>
+#include <cutter/cut-gassertions-helper.h>
 
 G_BEGIN_DECLS
 
