@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -136,8 +134,6 @@ set_property (GObject      *object,
 
     switch (prop_id) {
       case PROP_SO_FILENAME:
-        if (priv->so_filename)
-            g_free(priv->so_filename);
         priv->so_filename = g_value_dup_string(value);
         break;
       default:
@@ -386,9 +382,9 @@ create_test_case (CutLoader *loader)
     CutSetupFunction setup_function = NULL;
     CutGetCurrentTestContextFunction get_current_test_context_function = NULL;
     CutSetCurrentTestContextFunction set_current_test_context_function = NULL;
-    CutInitializeFunction initialize_function = NULL;
-    CutFinalizeFunction finalize_function = NULL;
-    CutTearDownFunction teardown_function = NULL;
+    CutStartupFunction startup_function = NULL;
+    CutShutdownFunction shutdown_function = NULL;
+    CutTeardownFunction teardown_function = NULL;
     gchar *test_case_name, *filename;
 
     priv = CUT_LOADER_GET_PRIVATE(loader);
@@ -406,11 +402,11 @@ create_test_case (CutLoader *loader)
                     "set_current_test_context",
                     (gpointer)&set_current_test_context_function);
     g_module_symbol(priv->module,
-                    "initialize",
-                    (gpointer)&initialize_function);
+                    "startup",
+                    (gpointer)&startup_function);
     g_module_symbol(priv->module,
-                    "finalize",
-                    (gpointer)&finalize_function);
+                    "shutdown",
+                    (gpointer)&shutdown_function);
 
     filename = g_path_get_basename(priv->so_filename);
     if (g_str_has_prefix(filename, "lib")) {
@@ -427,8 +423,8 @@ create_test_case (CutLoader *loader)
                                   teardown_function,
                                   get_current_test_context_function,
                                   set_current_test_context_function,
-                                  initialize_function,
-                                  finalize_function);
+                                  startup_function,
+                                  shutdown_function);
     g_free(test_case_name);
 
     g_object_ref(loader);
