@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -44,8 +42,8 @@
 static gboolean initialized = FALSE;
 static gchar *test_directory = NULL;
 static gchar *source_directory = NULL;
-static const gchar **test_case_names = NULL;
-static const gchar **test_names = NULL;
+static gchar **test_case_names = NULL;
+static gchar **test_names = NULL;
 static CutOrder test_case_order = CUT_ORDER_NONE_SPECIFIED;
 static gboolean use_multi_thread = FALSE;
 static GList *factories = NULL;
@@ -81,27 +79,9 @@ parse_test_case_order (const gchar *option_name, const gchar *value,
     return TRUE;
 }
 
-static gboolean
-print_help_all (const gchar *option_name, const gchar *value,
-                gpointer data, GError **error)
-{
-    GOptionContext *context = data;
-    gchar *help;
-
-    cut_contractor_build_all_factories(contractor);
-
-    help = g_option_context_get_help(context, FALSE, NULL);
-    g_print("%s", help);
-    g_free(help);
-    g_option_context_free(context);
-    exit(0);
-
-    return TRUE;
-}
-
 static const GOptionEntry option_entries[] =
 {
-    {"version", 0, 0, G_OPTION_ARG_CALLBACK, print_version,
+    {"version", 0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, print_version,
      N_("Show version"), NULL},
     {"source-directory", 's', 0, G_OPTION_ARG_STRING, &source_directory,
      N_("Set directory of source code"), "DIRECTORY"},
@@ -113,14 +93,13 @@ static const GOptionEntry option_entries[] =
      N_("Run test cases with multi-thread"), NULL},
     {"test-case-order", 0, 0, G_OPTION_ARG_CALLBACK, parse_test_case_order,
      N_("Sort test case by. Default is 'none'."), "[none|name|name-desc]"},
-    {"help-all", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_CALLBACK, print_help_all,
-     NULL, NULL},
     {NULL}
 };
 
 void
 cut_init (int *argc, char ***argv)
 {
+    int i;
     GOptionContext *option_context;
     GOptionGroup *main_group;
     GError *error = NULL;
@@ -161,7 +140,15 @@ cut_init (int *argc, char ***argv)
         exit(1);
     }
 
-    factories = cut_contractor_build_factories(contractor);
+    for (i = 1; i < *argc; i++) {
+        if (g_str_has_prefix((*argv)[i], "--help-")) {
+            factories = cut_contractor_build_all_factories(contractor);
+            break;
+        }
+    }
+
+    if (!factories)
+        factories = cut_contractor_build_factories(contractor);
 
     g_option_context_set_help_enabled(option_context, TRUE);
     g_option_context_set_ignore_unknown_options(option_context, FALSE);
@@ -268,11 +255,28 @@ remove_listeners (CutRunner *runner, GList *listeners)
     }
 }
 
+static CutUI *
+get_cut_ui (GList *listeners)
+{
+    GList *node;
+
+    for (node = listeners; node; node = g_list_next(node)) {
+        CutListener *listener = node->data;
+
+        if (CUT_IS_UI(listener)) {
+            return CUT_UI(listener);
+        }
+    }
+
+    return NULL;
+}
+
 gboolean
 cut_run_runner (CutRunner *runner)
 {
     gboolean success;
     GList *listeners;
+    CutUI *ui;
 
     if (!initialized) {
         g_warning("not initialized");
@@ -281,7 +285,13 @@ cut_run_runner (CutRunner *runner)
 
     listeners = create_listeners();
     add_listeners(runner, listeners);
-    success = cut_runner_run(runner);
+
+    ui = get_cut_ui(listeners);
+    if (ui)
+        success = cut_ui_run(ui, runner);
+    else
+        success = cut_runner_run(runner);
+
     remove_listeners(runner, listeners);
     g_list_free(listeners);
 
