@@ -67,11 +67,16 @@ const char *cut_test_context_take_string    (CutTestContext *context,
 const char *cut_test_context_take_printf    (CutTestContext *context,
                                              const char     *format,
                                              ...) CUT_GNUC_PRINTF(2, 3);
+const char **cut_test_context_take_string_array
+                                            (CutTestContext *context,
+                                             char          **strings);
 
 
 int   cut_utils_compare_string_array        (char **strings1,
                                              char **strings2);
 char *cut_utils_inspect_string_array        (char **strings);
+int   cut_utils_is_interested_diff          (const char *diff);
+int   cut_utils_file_exist                  (const char *path);
 
 void *cut_test_context_get_user_data        (CutTestContext *context);
 int   cut_test_context_trap_fork            (CutTestContext *context,
