@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -40,12 +38,15 @@ struct _CutRunnerPrivate
 {
     guint n_tests;
     guint n_assertions;
+    guint n_successes;
     guint n_failures;
     guint n_errors;
     guint n_pendings;
     guint n_notifications;
+    guint n_omissions;
     GList *results;
     gboolean use_multi_thread;
+    gboolean is_multi_thread;
     GMutex *mutex;
     gboolean crashed;
     gchar *stack_trace;
@@ -64,11 +65,14 @@ enum
     PROP_0,
     PROP_N_TESTS,
     PROP_N_ASSERTIONS,
+    PROP_N_SUCCESSES,
     PROP_N_FAILURES,
     PROP_N_ERRORS,
     PROP_N_PENDINGS,
     PROP_N_NOTIFICATIONS,
+    PROP_N_OMISSIONS,
     PROP_USE_MULTI_THREAD,
+    PROP_IS_MULTI_THREAD,
     PROP_TEST_CASE_ORDER
 };
 
@@ -88,12 +92,14 @@ enum
     ERROR_TEST,
     PENDING_TEST,
     NOTIFICATION_TEST,
+    OMISSION_TEST,
 
     SUCCESS_TEST_CASE,
     FAILURE_TEST_CASE,
     ERROR_TEST_CASE,
     PENDING_TEST_CASE,
     NOTIFICATION_TEST_CASE,
+    OMISSION_TEST_CASE,
 
     COMPLETE_TEST,
     COMPLETE_TEST_CASE,
@@ -144,6 +150,13 @@ cut_runner_class_init (CutRunnerClass *klass)
                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_N_ASSERTIONS, spec);
 
+    spec = g_param_spec_uint("n-successes",
+                             "Number of successes",
+                             "The number of successes of the runner",
+                             0, G_MAXUINT32, 0,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class, PROP_N_SUCCESSES, spec);
+
     spec = g_param_spec_uint("n-failures",
                              "Number of failures",
                              "The number of failures of the runner",
@@ -165,6 +178,20 @@ cut_runner_class_init (CutRunnerClass *klass)
                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_N_PENDINGS, spec);
 
+    spec = g_param_spec_uint("n-notifications",
+                             "Number of notifications",
+                             "The number of notifications of the runner",
+                             0, G_MAXUINT32, 0,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class, PROP_N_NOTIFICATIONS, spec);
+
+    spec = g_param_spec_uint("n-omissions",
+                             "Number of omissions",
+                             "The number of omissions of the runner",
+                             0, G_MAXUINT32, 0,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class, PROP_N_OMISSIONS, spec);
+
     spec = g_param_spec_boolean("use-multi-thread",
                                 "Use multi thread",
                                 "Whether use multi thread or not in the runner",
@@ -172,6 +199,13 @@ cut_runner_class_init (CutRunnerClass *klass)
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_USE_MULTI_THREAD, spec);
 
+    spec = g_param_spec_boolean("is-multi-thread",
+                                "Is multi thread?",
+                                "Whether the runner is running tests with multi thread",
+                                FALSE,
+                                G_PARAM_READWRITE);
+    g_object_class_install_property(gobject_class, PROP_IS_MULTI_THREAD, spec);
+
     spec = g_param_spec_enum("test-case-order",
                              "Test case order",
                              "Sort key for test case",
@@ -292,6 +326,17 @@ cut_runner_class_init (CutRunnerClass *klass)
                         CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
                         CUT_TYPE_TEST_RESULT);
 
+    signals[OMISSION_TEST]
+        = g_signal_new("omission-test",
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunnerClass, omission_test),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
+                       G_TYPE_NONE, 3,
+                       CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
+                       CUT_TYPE_TEST_RESULT);
+
     signals[COMPLETE_TEST]
         = g_signal_new ("complete-test",
                         G_TYPE_FROM_CLASS (klass),
@@ -356,6 +401,17 @@ cut_runner_class_init (CutRunnerClass *klass)
                         CUT_TYPE_TEST_CASE, CUT_TYPE_TEST_CONTEXT,
                         CUT_TYPE_TEST_RESULT);
 
+    signals[OMISSION_TEST_CASE]
+        = g_signal_new("omission-test-case",
+                       G_TYPE_FROM_CLASS (klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutRunnerClass, omission_test_case),
+                       NULL, NULL,
+                       _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
+                       G_TYPE_NONE, 3,
+                       CUT_TYPE_TEST_CASE, CUT_TYPE_TEST_CONTEXT,
+                       CUT_TYPE_TEST_RESULT);
+
     signals[COMPLETE_TEST_CASE]
         = g_signal_new ("complete-test-case",
                         G_TYPE_FROM_CLASS (klass),
@@ -393,12 +449,15 @@ cut_runner_init (CutRunner *runner)
 
     priv->n_tests = 0;
     priv->n_assertions = 0;
+    priv->n_successes = 0;
     priv->n_failures = 0;
     priv->n_errors = 0;
     priv->n_pendings = 0;
     priv->n_notifications = 0;
+    priv->n_omissions = 0;
     priv->results = NULL;
     priv->use_multi_thread = FALSE;
+    priv->is_multi_thread = FALSE;
     priv->mutex = g_mutex_new();
     priv->crashed = FALSE;
     priv->stack_trace = NULL;
@@ -474,6 +533,9 @@ set_property (GObject      *object,
       case PROP_N_ASSERTIONS:
         priv->n_assertions = g_value_get_uint(value);
         break;
+      case PROP_N_SUCCESSES:
+        priv->n_successes = g_value_get_uint(value);
+        break;
       case PROP_N_FAILURES:
         priv->n_failures = g_value_get_uint(value);
         break;
@@ -486,9 +548,15 @@ set_property (GObject      *object,
       case PROP_N_NOTIFICATIONS:
         priv->n_notifications = g_value_get_uint(value);
         break;
+      case PROP_N_OMISSIONS:
+        priv->n_omissions = g_value_get_uint(value);
+        break;
       case PROP_USE_MULTI_THREAD:
         priv->use_multi_thread = g_value_get_boolean(value);
         break;
+      case PROP_IS_MULTI_THREAD:
+        priv->is_multi_thread = g_value_get_boolean(value);
+        break;
       case PROP_TEST_CASE_ORDER:
         priv->test_case_order = g_value_get_enum(value);
         break;
@@ -513,6 +581,9 @@ get_property (GObject    *object,
       case PROP_N_ASSERTIONS:
         g_value_set_uint(value, priv->n_assertions);
         break;
+      case PROP_N_SUCCESSES:
+        g_value_set_uint(value, priv->n_successes);
+        break;
       case PROP_N_FAILURES:
         g_value_set_uint(value, priv->n_failures);
         break;
@@ -525,9 +596,15 @@ get_property (GObject    *object,
       case PROP_N_NOTIFICATIONS:
         g_value_set_uint(value, priv->n_notifications);
         break;
+      case PROP_N_OMISSIONS:
+        g_value_set_uint(value, priv->n_omissions);
+        break;
       case PROP_USE_MULTI_THREAD:
         g_value_set_boolean(value, priv->use_multi_thread);
         break;
+      case PROP_IS_MULTI_THREAD:
+        g_value_set_boolean(value, priv->is_multi_thread);
+        break;
       case PROP_TEST_CASE_ORDER:
         g_value_set_enum(value, priv->test_case_order);
         break;
@@ -555,6 +632,7 @@ cut_runner_copy (CutRunner *runner)
     copied_priv = CUT_RUNNER_GET_PRIVATE(copied);
 
     copied_priv->use_multi_thread = priv->use_multi_thread;
+    copied_priv->is_multi_thread = priv->is_multi_thread;
 
     copied_priv->test_directory = g_strdup(priv->test_directory);
     copied_priv->source_directory = g_strdup(priv->source_directory);
@@ -603,6 +681,8 @@ cut_runner_set_multi_thread (CutRunner *runner, gboolean use_multi_thread)
 
     g_mutex_lock(priv->mutex);
     priv->use_multi_thread = use_multi_thread;
+    if (use_multi_thread)
+        priv->is_multi_thread = TRUE;
     g_mutex_unlock(priv->mutex);
 }
 
@@ -612,38 +692,42 @@ cut_runner_get_multi_thread (CutRunner *runner)
     return CUT_RUNNER_GET_PRIVATE(runner)->use_multi_thread;
 }
 
+gboolean
+cut_runner_is_multi_thread (CutRunner *runner)
+{
+    return CUT_RUNNER_GET_PRIVATE(runner)->is_multi_thread;
+}
+
 void
-cut_runner_set_target_test_case_names (CutRunner *runner,
-                                        const gchar **names)
+cut_runner_set_target_test_case_names (CutRunner *runner, gchar **names)
 {
     CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
 
     g_strfreev(priv->target_test_case_names);
-    priv->target_test_case_names = g_strdupv((gchar **)names);
+    priv->target_test_case_names = g_strdupv(names);
 }
 
-const gchar **
+gchar **
 cut_runner_get_target_test_case_names (CutRunner *runner)
 {
     CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
-    return (const gchar **)(priv->target_test_case_names);
+    return priv->target_test_case_names;
 }
 
 void
-cut_runner_set_target_test_names (CutRunner *runner,
-                                   const gchar **names)
+cut_runner_set_target_test_names (CutRunner *runner, gchar **names)
 {
     CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
 
     g_strfreev(priv->target_test_names);
-    priv->target_test_names = g_strdupv((gchar **)names);
+    priv->target_test_names = g_strdupv(names);
 }
 
-const gchar **
+gchar **
 cut_runner_get_target_test_names (CutRunner *runner)
 {
     CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
-    return (const gchar **)(priv->target_test_names);
+    return priv->target_test_names;
 }
 
 static void
@@ -670,6 +754,7 @@ cb_success (CutTest *test, CutTestContext *test_context, CutTestResult *result,
     priv = CUT_RUNNER_GET_PRIVATE(runner);
     g_mutex_lock(priv->mutex);
     priv->results = g_list_prepend(priv->results, g_object_ref(result));
+    priv->n_successes++;
     g_mutex_unlock(priv->mutex);
 
     g_signal_emit(runner, signals[SUCCESS_TEST], 0, test, test_context, result);
@@ -739,6 +824,22 @@ cb_notification (CutTest *test, CutTestContext *test_context,
     g_signal_emit(runner, signals[NOTIFICATION_TEST], 0, test, test_context, result);
 }
 
+static void
+cb_omission (CutTest *test, CutTestContext *test_context,
+             CutTestResult *result, gpointer data)
+{
+    CutRunner *runner = data;
+    CutRunnerPrivate *priv;
+
+    priv = CUT_RUNNER_GET_PRIVATE(runner);
+    g_mutex_lock(priv->mutex);
+    priv->results = g_list_prepend(priv->results, g_object_ref(result));
+    priv->n_omissions++;
+    g_mutex_unlock(priv->mutex);
+
+    g_signal_emit(runner, signals[OMISSION_TEST], 0, test, test_context, result);
+}
+
 static void
 cb_complete (CutTest *test, gpointer data)
 {
@@ -760,13 +861,16 @@ cb_complete (CutTest *test, gpointer data)
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_notification),
                                          data);
+    g_signal_handlers_disconnect_by_func(test,
+                                         G_CALLBACK(cb_omission),
+                                         data);
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_complete),
                                          data);
 }
 
 void
-cut_runner_start_test (CutRunner *runner, CutTest *test)
+cut_runner_prepare_test (CutRunner *runner, CutTest *test)
 {
     CutRunnerPrivate *priv;
 
@@ -782,6 +886,7 @@ cut_runner_start_test (CutRunner *runner, CutTest *test)
     g_signal_connect(test, "error", G_CALLBACK(cb_error), runner);
     g_signal_connect(test, "pending", G_CALLBACK(cb_pending), runner);
     g_signal_connect(test, "notification", G_CALLBACK(cb_notification), runner);
+    g_signal_connect(test, "omission", G_CALLBACK(cb_omission), runner);
     g_signal_connect(test, "complete", G_CALLBACK(cb_complete), runner);
 }
 
@@ -853,6 +958,16 @@ cb_notification_test_case (CutTestCase *test_case, CutTestContext *test_context,
                   test_case, test_context, result);
 }
 
+static void
+cb_omission_test_case (CutTestCase *test_case, CutTestContext *test_context,
+                       CutTestResult *result, gpointer data)
+{
+    CutRunner *runner = data;
+
+    g_signal_emit(runner, signals[OMISSION_TEST_CASE], 0,
+                  test_case, test_context, result);
+}
+
 static void
 cb_start_test_case(CutTestCase *test_case, gpointer data)
 {
@@ -893,6 +1008,7 @@ cb_complete_test_case(CutTestCase *test_case, gpointer data)
     DISCONNECT(error);
     DISCONNECT(pending);
     DISCONNECT(notification);
+    DISCONNECT(omission);
 
     DISCONNECT(ready);
     DISCONNECT(start);
@@ -903,7 +1019,7 @@ cb_complete_test_case(CutTestCase *test_case, gpointer data)
 }
 
 void
-cut_runner_start_test_case (CutRunner *runner, CutTestCase *test_case)
+cut_runner_prepare_test_case (CutRunner *runner, CutTestCase *test_case)
 {
 #define CONNECT(name) \
     g_signal_connect(test_case, #name, G_CALLBACK(cb_ ## name), runner)
@@ -921,6 +1037,7 @@ cut_runner_start_test_case (CutRunner *runner, CutTestCase *test_case)
     CONNECT(error);
     CONNECT(pending);
     CONNECT(notification);
+    CONNECT(omission);
 
     CONNECT(ready);
     CONNECT(start);
@@ -983,7 +1100,7 @@ cb_complete_test_suite(CutTestSuite *test_suite, gpointer data)
 }
 
 void
-cut_runner_start_test_suite (CutRunner *runner, CutTestSuite *test_suite)
+cut_runner_prepare_test_suite (CutRunner *runner, CutTestSuite *test_suite)
 {
 #define CONNECT(name)                                                \
     g_signal_connect(test_suite, #name,                              \
@@ -1010,6 +1127,12 @@ cut_runner_get_n_assertions (CutRunner *runner)
     return CUT_RUNNER_GET_PRIVATE(runner)->n_assertions;
 }
 
+guint
+cut_runner_get_n_successes (CutRunner *runner)
+{
+    return CUT_RUNNER_GET_PRIVATE(runner)->n_successes;
+}
+
 guint
 cut_runner_get_n_failures (CutRunner *runner)
 {
@@ -1034,6 +1157,12 @@ cut_runner_get_n_notifications (CutRunner *runner)
     return CUT_RUNNER_GET_PRIVATE(runner)->n_notifications;
 }
 
+guint
+cut_runner_get_n_omissions (CutRunner *runner)
+{
+    return CUT_RUNNER_GET_PRIVATE(runner)->n_omissions;
+}
+
 const GList *
 cut_runner_get_results (CutRunner *runner)
 {
