@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -91,6 +89,10 @@ struct _CutRunnerClass
                                  CutTest        *test,
                                  CutTestContext *test_context,
                                  CutTestResult  *result);
+    void (*omission_test)       (CutRunner      *runner,
+                                 CutTest        *test,
+                                 CutTestContext *test_context,
+                                 CutTestResult  *result);
     void (*complete_test)       (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context);
@@ -115,6 +117,10 @@ struct _CutRunnerClass
                                     CutTestCase    *test_case,
                                     CutTestContext *test_context,
                                     CutTestResult  *result);
+    void (*omission_test_case)  (CutRunner      *runner,
+                                 CutTestCase    *test_case,
+                                 CutTestContext *test_context,
+                                 CutTestResult  *result);
     void (*complete_test_case)  (CutRunner      *runner,
                                  CutTestCase    *test_case);
 
@@ -141,27 +147,30 @@ const gchar  *cut_runner_get_source_directory      (CutRunner   *runner);
 void          cut_runner_set_multi_thread          (CutRunner   *runner,
                                                     gboolean     use_multi_thread);
 gboolean      cut_runner_get_multi_thread          (CutRunner   *runner);
+gboolean      cut_runner_is_multi_thread           (CutRunner   *runner);
 
 void          cut_runner_set_target_test_case_names(CutRunner   *runner,
-                                                    const gchar **names);
-const gchar **cut_runner_get_target_test_case_names(CutRunner   *runner);
+                                                    gchar      **names);
+gchar       **cut_runner_get_target_test_case_names(CutRunner   *runner);
 void          cut_runner_set_target_test_names     (CutRunner   *runner,
-                                                    const gchar **names);
-const gchar **cut_runner_get_target_test_names     (CutRunner   *runner);
+                                                    gchar      **names);
+gchar       **cut_runner_get_target_test_names     (CutRunner   *runner);
 
-void          cut_runner_start_test                (CutRunner   *runner,
+void          cut_runner_prepare_test              (CutRunner   *runner,
                                                     CutTest     *test);
-void          cut_runner_start_test_case           (CutRunner   *runner,
+void          cut_runner_prepare_test_case         (CutRunner   *runner,
                                                     CutTestCase *test_case);
-void          cut_runner_start_test_suite          (CutRunner   *runner,
+void          cut_runner_prepare_test_suite        (CutRunner   *runner,
                                                     CutTestSuite *test_suite);
 
 guint         cut_runner_get_n_tests               (CutRunner *runner);
+guint         cut_runner_get_n_successes           (CutRunner *runner);
 guint         cut_runner_get_n_assertions          (CutRunner *runner);
 guint         cut_runner_get_n_failures            (CutRunner *runner);
 guint         cut_runner_get_n_errors              (CutRunner *runner);
 guint         cut_runner_get_n_pendings            (CutRunner *runner);
 guint         cut_runner_get_n_notifications       (CutRunner *runner);
+guint         cut_runner_get_n_omissions           (CutRunner *runner);
 
 const GList  *cut_runner_get_results               (CutRunner *runner);
 
