@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -35,8 +33,8 @@ G_BEGIN_DECLS
 #define CUT_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CUT_TYPE_TEST_CASE))
 #define CUT_TEST_CASE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), CUT_TYPE_TEST_CASE, CutTestCaseClass))
 
-typedef void (*CutInitializeFunction) (void);
-typedef void (*CutFinalizeFunction)   (void);
+typedef void (*CutStartupFunction) (void);
+typedef void (*CutShutdownFunction)   (void);
 
 typedef struct _CutTestCaseClass CutTestCaseClass;
 
@@ -63,27 +61,27 @@ GType        cut_test_case_get_type       (void) G_GNUC_CONST;
 
 CutTestCase *cut_test_case_new            (const gchar *name,
                                            CutSetupFunction setup_function,
-                                           CutTearDownFunction teardown_function,
+                                           CutTeardownFunction teardown_function,
                                            CutGetCurrentTestContextFunction
                                            get_current_test_context_function,
                                            CutSetCurrentTestContextFunction
                                            set_current_test_context_function,
-                                           CutInitializeFunction
-                                           initialize_function,
-                                           CutFinalizeFunction
-                                           finalize_function);
+                                           CutStartupFunction
+                                           startup_function,
+                                           CutShutdownFunction
+                                           shutdown_function);
 void         cut_test_case_add_test       (CutTestCase *test_case,
                                            CutTest *test);
 guint        cut_test_case_get_n_tests    (CutTestCase  *test_case,
-                                           const gchar **test_names);
+                                           gchar       **test_names);
 gboolean     cut_test_case_run            (CutTestCase  *test_case,
                                            CutRunner    *runner);
 gboolean     cut_test_case_run_test       (CutTestCase  *test_case,
                                            CutRunner    *runner,
-                                           const gchar  *name);
+                                           gchar        *name);
 gboolean     cut_test_case_run_with_filter(CutTestCase  *test_case,
                                            CutRunner    *runner,
-                                           const gchar **test_names);
+                                           gchar       **test_names);
 
 G_END_DECLS
 
