@@ -46,6 +46,8 @@ struct _CutTestContextPrivate
     gboolean is_multi_thread;
     jmp_buf *jump_buffer;
     GList *taken_strings;
+    GList *taken_string_arrays;
+    GList *taken_objects;
     gpointer user_data;
     GDestroyNotify user_data_destroy_notify;
     GList *processes;
@@ -120,6 +122,7 @@ cut_test_context_init (CutTestContext *context)
     priv->is_multi_thread = FALSE;
 
     priv->taken_strings = NULL;
+    priv->taken_string_arrays = NULL;
 
     priv->user_data = NULL;
     priv->user_data_destroy_notify = NULL;
@@ -157,6 +160,18 @@ dispose (GObject *object)
     g_list_free(priv->taken_strings);
     priv->taken_strings = NULL;
 
+    if (priv->taken_string_arrays) {
+        g_list_foreach(priv->taken_string_arrays, (GFunc)g_strfreev, NULL);
+        g_list_free(priv->taken_string_arrays);
+        priv->taken_string_arrays = NULL;
+    }
+
+    if (priv->taken_objects) {
+        g_list_foreach(priv->taken_objects, (GFunc)g_object_unref, NULL);
+        g_list_free(priv->taken_objects);
+        priv->taken_objects = NULL;
+    }
+
     if (priv->user_data && priv->user_data_destroy_notify)
         priv->user_data_destroy_notify(priv->user_data);
     priv->user_data = NULL;
@@ -447,6 +462,31 @@ cut_test_context_take_printf (CutTestContext *context, const char *format, ...)
     return taken_string;
 }
 
+const char **
+cut_test_context_take_string_array (CutTestContext *context,
+                                    char          **strings)
+{
+    CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    char **taken_strings;
+
+    taken_strings = g_strdupv(strings);
+    priv->taken_string_arrays = g_list_prepend(priv->taken_string_arrays, taken_strings);
+    g_strfreev(strings);
+
+    return (const char **)taken_strings;
+}
+
+GObject *
+cut_test_context_take_g_object (CutTestContext *context,
+                                GObject        *object)
+{
+    CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    priv->taken_objects = g_list_prepend(priv->taken_objects, object);
+
+    return object;
+}
+
 int
 cut_test_context_trap_fork (CutTestContext *context,
                             const gchar *function_name,
