@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -32,6 +30,7 @@
 #include "cut-test.h"
 #include "cut-test-case.h"
 #include "cut-test-suite.h"
+#include "cut-xml-parser.h"
 
 #define CUT_TEST_RESULT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_RESULT, CutTestResultPrivate))
 
@@ -96,56 +95,56 @@ cut_test_result_class_init (CutTestResultClass *klass)
                              "The status of the result",
                              CUT_TYPE_TEST_RESULT_STATUS,
                              CUT_TEST_RESULT_SUCCESS,
-                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                             G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_STATUS, spec);
 
     spec = g_param_spec_object("test",
                                "CutTest object",
                                "A CutTest object",
                                CUT_TYPE_TEST,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_TEST, spec);
 
     spec = g_param_spec_object("test-case",
                                "CutTestCase object",
                                "A CutTestCase object",
                                CUT_TYPE_TEST_CASE,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_TEST_CASE, spec);
 
     spec = g_param_spec_object("test-suite",
                                "CutTestSuite object",
                                "A CutTestSuite object",
                                CUT_TYPE_TEST_SUITE,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_TEST_SUITE, spec);
 
     spec = g_param_spec_string("user-message",
                                "User Message",
                                "The message from user of the result",
                                NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_USER_MESSAGE, spec);
 
     spec = g_param_spec_string("system-message",
                                "System Message",
                                "The message from system of the result",
                                NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_SYSTEM_MESSAGE, spec);
 
     spec = g_param_spec_string("function-name",
                                "Function name",
                                "The function name of the result",
                                NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_FUNCTION_NAME, spec);
 
     spec = g_param_spec_string("filename",
                                "Filename",
                                "The filename of the result",
                                NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_FILENAME, spec);
 
     spec = g_param_spec_uint("line",
@@ -244,45 +243,35 @@ set_property (GObject      *object,
         priv->status = g_value_get_enum(value);
         break;
       case PROP_TEST:
-        if (priv->test)
-            g_object_unref(priv->test);
-        if (g_value_get_object(value))
-            priv->test = g_object_ref(g_value_get_object(value));
+        cut_test_result_set_test(CUT_TEST_RESULT(object),
+                                 g_value_get_object(value));
         break;
       case PROP_TEST_CASE:
-        if (priv->test_case)
-            g_object_unref(priv->test_case);
-        if (g_value_get_object(value))
-            priv->test_case = g_object_ref(g_value_get_object(value));
+        cut_test_result_set_test_case(CUT_TEST_RESULT(object),
+                                      g_value_get_object(value));
         break;
       case PROP_TEST_SUITE:
-        if (priv->test_suite)
-            g_object_unref(priv->test_suite);
-        if (g_value_get_object(value))
-            priv->test_suite = g_object_ref(g_value_get_object(value));
+        cut_test_result_set_test_suite(CUT_TEST_RESULT(object),
+                                       g_value_get_object(value));
         break;
       case PROP_USER_MESSAGE:
-        if (priv->user_message)
-            g_free(priv->user_message);
-        priv->user_message = g_value_dup_string(value);
+        cut_test_result_set_user_message(CUT_TEST_RESULT(object),
+                                         g_value_get_string(value));
         if (priv->message)
             g_free(priv->message);
         priv->message = NULL;
       case PROP_SYSTEM_MESSAGE:
-        if (priv->system_message)
-            g_free(priv->system_message);
-        priv->system_message = g_value_dup_string(value);
+        cut_test_result_set_system_message(CUT_TEST_RESULT(object),
+                                           g_value_get_string(value));
         if (priv->message)
             g_free(priv->message);
         priv->message = NULL;
       case PROP_FUNCTION_NAME:
-        if (priv->function_name)
-            g_free(priv->function_name);
-        priv->function_name = g_value_dup_string(value);
+        cut_test_result_set_function_name(CUT_TEST_RESULT(object),
+                                          g_value_get_string(value));
       case PROP_FILENAME:
-        if (priv->filename)
-            g_free(priv->filename);
-        priv->filename = g_value_dup_string(value);
+        cut_test_result_set_filename(CUT_TEST_RESULT(object),
+                                     g_value_get_string(value));
         break;
       case PROP_LINE:
         priv->line = g_value_get_uint(value);
@@ -365,6 +354,12 @@ cut_test_result_new (CutTestResultStatus status,
                         NULL);
 }
 
+CutTestResult *
+cut_test_result_new_from_xml (const gchar *xml, gssize length)
+{
+    return cut_xml_parse_test_result_xml(xml, length);
+}
+
 CutTestResultStatus
 cut_test_result_get_status (CutTestResult *result)
 {
@@ -469,10 +464,189 @@ cut_test_result_get_elapsed (CutTestResult *result)
     return CUT_TEST_RESULT_GET_PRIVATE(result)->elapsed;
 }
 
+static void
+append_indent (GString *string, guint indent)
+{
+    guint i;
+    for (i = 0; i < indent; i++)
+        g_string_append_c(string, ' ');
+
+}
+
+static void
+append_element_with_value (GString *string, guint indent, const gchar *element_name, const gchar *value)
+{
+    gchar *escaped;
+    append_indent(string, indent);
+    escaped = g_markup_printf_escaped("<%s>%s</%s>\n",
+                                      element_name,
+                                      value,
+                                      element_name);
+    g_string_append(string, escaped);
+    g_free(escaped);
+}
+
+static const gchar *
+result_status_to_name (CutTestResultStatus status)
+{
+    switch (status) {
+      case CUT_TEST_RESULT_SUCCESS:
+        return "success";
+        break;
+      case CUT_TEST_RESULT_FAILURE:
+        return "failure";
+        break;
+      case CUT_TEST_RESULT_ERROR:
+        return "error";
+        break;
+      case CUT_TEST_RESULT_PENDING:
+        return "pending";
+        break;
+      case CUT_TEST_RESULT_NOTIFICATION:
+        return "notification";
+        break;
+      default:
+        return "unknown status";
+        break;
+    }
+}
+
+static void
+append_element_valist (GString *string, guint indent, const gchar *element_name, va_list var_args)
+{
+    const gchar *name;
+
+    name = element_name;
+
+    while (name) {
+        const gchar *value = va_arg(var_args, gchar *);
+        if (value)
+            append_element_with_value(string, indent, name, value);
+        name = va_arg(var_args, gchar *);
+    }
+}
+
+static void
+append_element_with_children (GString *string, guint indent,
+                              const gchar *element_name,
+                              const gchar *first_child_element, ...)
+{
+    gchar *escaped;
+    va_list var_args;
+
+    escaped = g_markup_escape_text(element_name, -1);
+    append_indent(string, indent);
+    g_string_append_printf(string, "<%s>\n", escaped);
+
+    va_start(var_args, first_child_element);
+    append_element_valist(string, indent + 2, first_child_element, var_args);
+    va_end(var_args);
+
+    append_indent(string, indent);
+    g_string_append_printf(string, "</%s>\n", escaped);
+    g_free(escaped);
+}
+
+static void
+append_backtrace_to_string (GString *string, CutTestResult *result)
+{
+    gchar *line_string, *info_string;
+
+    line_string = g_strdup_printf("%d", cut_test_result_get_line(result));
+    info_string = g_strdup_printf("%s()", cut_test_result_get_function_name(result));
+
+    append_element_with_children(string, 4, "backtrace",
+                                 "file", cut_test_result_get_filename(result),
+                                 "line", line_string,
+                                 "info", info_string,
+                                 NULL);
+    g_free(line_string);
+    g_free(info_string);
+}
+
+static void
+append_test_result_to_string (GString *string, CutTestResult *result)
+{
+    CutTestResultStatus status;
+    gchar *elapsed_string;
+    const gchar *message;
+
+    elapsed_string = g_strdup_printf("%f", cut_test_result_get_elapsed(result));
+    message = cut_test_result_get_message(result);
+    status = cut_test_result_get_status(result);
+
+    append_element_with_value(string, 4, "status", result_status_to_name(status));
+    if (message)
+        append_element_with_value(string, 4, "detail", message);
+    if (status != CUT_TEST_RESULT_SUCCESS)
+        append_backtrace_to_string(string, result);
+    append_element_with_value(string, 4, "elapsed", elapsed_string);
+    g_free(elapsed_string);
+}
+
+static void
+append_attribute (const gchar *key, const gchar *value, GString *string)
+{
+    guint indent = 6;
+
+    if (!strcmp(key, "description"))
+        return;
+
+    append_indent(string, indent);
+    g_string_append(string, "<option>\n");
+
+    append_element_with_value(string, indent + 2, "name", key);
+    append_element_with_value(string, indent + 2, "value", value);
+
+    append_indent(string, indent);
+    g_string_append(string, "</option>\n");
+}
+
+static void
+append_test_info_to_string (GString *string, const gchar *element_name, CutTest *test)
+{
+    gchar *escaped;
+    const gchar *description, *name;
+    guint indent = 4;
+    GHashTable *attributes;
+
+    if (!test)
+        return;
+
+    escaped = g_markup_escape_text(element_name, -1);
+    append_indent(string, indent);
+    g_string_append_printf(string, "<%s>\n", escaped);
+
+    name = cut_test_get_name(test);
+    if (name)
+        append_element_with_value(string, indent + 2, "name", name);
+
+    description = cut_test_get_description(test);
+    if (description)
+        append_element_with_value(string, indent + 2, "description", description);
+
+    attributes = (GHashTable *)cut_test_get_attributes(test);
+    if (attributes)
+        g_hash_table_foreach(attributes, (GHFunc)append_attribute, string);
+
+    append_indent(string, indent);
+    g_string_append_printf(string, "</%s>\n", escaped);
+    g_free(escaped);
+}
+
 gchar *
 cut_test_result_to_xml (CutTestResult *result)
 {
-    return strdup("_Not implemented yet");
+    GString *xml = g_string_new("");
+
+    g_string_append(xml, "  <result>\n");
+    append_test_info_to_string(xml, "test-case",
+                               CUT_TEST(cut_test_result_get_test_case(result)));
+    append_test_info_to_string(xml, "test", cut_test_result_get_test(result));
+    append_test_result_to_string(xml, result);
+    g_string_append(xml, "  </result>\n");
+
+    return g_string_free(xml, FALSE);
 }
 
 const gchar *
@@ -484,23 +658,164 @@ cut_test_result_status_to_signal_name (CutTestResultStatus status)
       case CUT_TEST_RESULT_SUCCESS:
         signal_name = "success";
         break;
+      case CUT_TEST_RESULT_NOTIFICATION:
+        signal_name = "notification";
+        break;
+      case CUT_TEST_RESULT_OMISSION:
+        signal_name = "omission";
+        break;
+      case CUT_TEST_RESULT_PENDING:
+        signal_name = "pending";
+        break;
       case CUT_TEST_RESULT_FAILURE:
         signal_name = "failure";
         break;
       case CUT_TEST_RESULT_ERROR:
         signal_name = "error";
         break;
-      case CUT_TEST_RESULT_PENDING:
-        signal_name = "pending";
-        break;
-      case CUT_TEST_RESULT_NOTIFICATION:
-        signal_name = "notification";
+      case CUT_TEST_RESULT_INVALID:
+        signal_name = "invalid status";
         break;
     }
 
     return signal_name;
 }
 
+gboolean
+cut_test_result_status_is_critical (CutTestResultStatus status)
+{
+    return status > CUT_TEST_RESULT_OMISSION;
+}
+
+void
+cut_test_result_set_status (CutTestResult *result, CutTestResultStatus status)
+{
+    CUT_TEST_RESULT_GET_PRIVATE(result)->status = status;
+}
+
+void
+cut_test_result_set_test (CutTestResult *result, CutTest *test)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test) {
+        g_object_unref(priv->test);
+        priv->test = NULL;
+    }
+    if (test)
+        priv->test = g_object_ref(test);
+}
+
+void
+cut_test_result_set_test_case (CutTestResult *result, CutTestCase *test_case)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test_case) {
+        g_object_unref(priv->test_case);
+        priv->test_case = NULL;
+    }
+    if (test_case)
+        priv->test_case = g_object_ref(test_case);
+}
+
+void
+cut_test_result_set_test_suite (CutTestResult *result, CutTestCase *test_suite)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->test_suite) {
+        g_object_unref(priv->test_suite);
+        priv->test_suite = NULL;
+    }
+    if (test_suite)
+        priv->test_suite = g_object_ref(test_suite);
+}
+
+void
+cut_test_result_set_user_message (CutTestResult *result,
+                                  const gchar *user_message)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->user_message) {
+        g_free(priv->user_message);
+        priv->user_message = NULL;
+    }
+    if (user_message)
+        priv->user_message = g_strdup(user_message);
+}
+
+void
+cut_test_result_set_message (CutTestResult *result,
+                             const gchar *message)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->message) {
+        g_free(priv->message);
+        priv->message = NULL;
+    }
+    if (message)
+        priv->message = g_strdup(message);
+}
+
+void
+cut_test_result_set_system_message (CutTestResult *result,
+                                    const gchar *system_message)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->system_message) {
+        g_free(priv->system_message);
+        priv->system_message = NULL;
+    }
+    if (system_message)
+        priv->system_message = g_strdup(system_message);
+}
+
+void
+cut_test_result_set_function_name (CutTestResult *result,
+                                   const gchar *function_name)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->function_name) {
+        g_free(priv->function_name);
+        priv->function_name = NULL;
+    }
+    if (function_name)
+        priv->function_name = g_strdup(function_name);
+}
+
+void
+cut_test_result_set_filename (CutTestResult *result,
+                              const gchar *filename)
+{
+    CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+
+    if (priv->filename) {
+        g_free(priv->filename);
+        priv->filename = NULL;
+    }
+    if (filename)
+        priv->filename = g_strdup(filename);
+}
+
+void
+cut_test_result_set_line (CutTestResult *result,
+                          guint line)
+{
+    CUT_TEST_RESULT_GET_PRIVATE(result)->line = line;
+}
+
+void
+cut_test_result_set_elapsed (CutTestResult *result,
+                             gdouble elapsed)
+{
+    CUT_TEST_RESULT_GET_PRIVATE(result)->elapsed = elapsed;
+}
+
 
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
