@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -59,6 +57,9 @@ CutTestResult *cut_test_result_new        (CutTestResultStatus status,
                                            const gchar *function_name,
                                            const gchar *filename,
                                            guint line);
+CutTestResult *cut_test_result_new_from_xml
+                                          (const gchar *xml,
+                                           gssize len);
 
 CutTestResultStatus  cut_test_result_get_status        (CutTestResult *result);
 CutTest             *cut_test_result_get_test          (CutTestResult *result);
@@ -73,14 +74,39 @@ const gchar         *cut_test_result_get_function_name (CutTestResult *result);
 const gchar         *cut_test_result_get_filename      (CutTestResult *result);
 guint                cut_test_result_get_line          (CutTestResult *result);
 gdouble              cut_test_result_get_elapsed       (CutTestResult *result);
-gchar               *cut_test_result_to_xml            (CutTestResult *result);
+
+void cut_test_result_set_status          (CutTestResult *result,
+                                          CutTestResultStatus status);
+void cut_test_result_set_test            (CutTestResult *result,
+                                          CutTest *test);
+void cut_test_result_set_test_case       (CutTestResult *result,
+                                          CutTestCase *test_case);
+void cut_test_result_set_test_suite      (CutTestResult *result,
+                                          CutTestCase *test_suite);
+void cut_test_result_set_message         (CutTestResult *result,
+                                          const gchar *message);
+void cut_test_result_set_user_message    (CutTestResult *result,
+                                          const gchar *user_message);
+void cut_test_result_set_system_message  (CutTestResult *result,
+                                          const gchar *system_message);
+void cut_test_result_set_function_name   (CutTestResult *result,
+                                          const gchar *function_name);
+void cut_test_result_set_filename        (CutTestResult *result,
+                                          const gchar *filename);
+void cut_test_result_set_line            (CutTestResult *result,
+                                          guint line);
+void cut_test_result_set_elapsed         (CutTestResult *result,
+                                          gdouble elapsed);
+
+gchar       *cut_test_result_to_xml                (CutTestResult *result);
 
 const gchar *cut_test_result_status_to_signal_name (CutTestResultStatus status);
+gboolean     cut_test_result_status_is_critical    (CutTestResultStatus status);
 
 G_END_DECLS
 
 #endif /* __CUT_TEST_RESULT_H__ */
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
