@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -60,6 +58,7 @@ enum
     ERROR,
     PENDING,
     NOTIFICATION,
+    OMISSION,
     COMPLETE,
     CRASHED,
     LAST_SIGNAL
@@ -99,7 +98,7 @@ cut_test_class_init (CutTestClass *klass)
                                "Test name",
                                "The name of the test",
                                NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                               G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_NAME, spec);
 
     spec = g_param_spec_pointer("test-function",
@@ -176,6 +175,16 @@ cut_test_class_init (CutTestClass *klass)
                         G_TYPE_NONE, 2,
                         CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
 
+    cut_test_signals[OMISSION]
+        = g_signal_new("omission",
+                        G_TYPE_FROM_CLASS(klass),
+                        G_SIGNAL_RUN_LAST,
+                        G_STRUCT_OFFSET(CutTestClass, omission),
+                        NULL, NULL,
+                        _cut_marshal_VOID__OBJECT_OBJECT,
+                        G_TYPE_NONE, 2,
+                        CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
+
     cut_test_signals[COMPLETE]
         = g_signal_new ("complete",
                         G_TYPE_FROM_CLASS (klass),
@@ -243,9 +252,7 @@ set_property (GObject      *object,
 
     switch (prop_id) {
       case PROP_NAME:
-        if (priv->name)
-            g_free(priv->name);
-        priv->name = g_value_dup_string(value);
+        cut_test_set_name(CUT_TEST(object), g_value_get_string(value));
         break;
       case PROP_TEST_FUNCTION:
         priv->test_function = g_value_get_pointer(value);
@@ -296,7 +303,7 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
     if (!priv->test_function)
         return FALSE;
 
-    cut_runner_start_test(runner, test);
+    cut_runner_prepare_test(runner, test);
 
     g_signal_emit_by_name(test, "start");
 
@@ -308,12 +315,10 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
             priv->timer = g_timer_new();
         }
         priv->test_function();
-        success = TRUE;
-    } else {
-        success = FALSE;
     }
     g_timer_stop(priv->timer);
 
+    success = !cut_test_context_is_failed(test_context);
     if (success) {
         CutTestResult *result;
         result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
@@ -322,7 +327,7 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
                                      NULL,
                                      NULL, NULL,
                                      NULL, NULL, 0);
-        g_object_set(result, "elapsed", cut_test_get_elapsed(test), NULL);
+        cut_test_result_set_elapsed(result, cut_test_get_elapsed(test));
         g_signal_emit_by_name(test, "success", test_context, result);
         g_object_unref(result);
     }
@@ -338,6 +343,20 @@ cut_test_get_name (CutTest *test)
     return CUT_TEST_GET_PRIVATE(test)->name;
 }
 
+void
+cut_test_set_name (CutTest *test, const gchar *name)
+{
+    CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
+
+    if (priv->name) {
+        g_free(priv->name);
+        priv->name = NULL;
+    }
+    
+    if (name)
+        priv->name = g_strdup(name);
+}
+
 const gchar *
 cut_test_get_description (CutTest *test)
 {
@@ -347,9 +366,8 @@ cut_test_get_description (CutTest *test)
 static gdouble
 real_get_elapsed (CutTest *test)
 {
-    CutTestPrivate *priv;
+    CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
 
-    priv = CUT_TEST_GET_PRIVATE(test);
     if (priv->timer)
         return g_timer_elapsed(priv->timer, NULL);
     else
