@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -39,12 +37,11 @@ G_BEGIN_DECLS
 
 typedef struct _CutTestClass    CutTestClass;
 
-typedef struct _CutTestResult         CutTestResult;
 typedef struct _CutTestResultClass    CutTestResultClass;
 
 typedef void    (*CutTestFunction)     (void);
 typedef void    (*CutSetupFunction)    (void);
-typedef void    (*CutTearDownFunction) (void);
+typedef void    (*CutTeardownFunction) (void);
 typedef CutTestContext *(*CutGetCurrentTestContextFunction) (void);
 typedef void            (*CutSetCurrentTestContextFunction) (CutTestContext *context);
 
@@ -75,6 +72,9 @@ struct _CutTestClass
     void (*notification)   (CutTest        *test,
                             CutTestContext *context,
                             CutTestResult  *result);
+    void (*omission)       (CutTest        *test,
+                            CutTestContext *context,
+                            CutTestResult  *result);
     void (*complete)       (CutTest        *test);
     void (*crashed)        (CutTest        *test,
                             const gchar    *stack_trace);
@@ -89,19 +89,19 @@ CutTest     *cut_test_new                 (const gchar    *name,
 gboolean     cut_test_run                 (CutTest        *test,
                                            CutTestContext *test_context,
                                            CutRunner      *runner);
-void         cut_test_stop_timer          (CutTest *test);        
 
-const gchar *cut_test_get_name            (CutTest *test);
-const gchar *cut_test_get_description     (CutTest *test);
-
-gdouble      cut_test_get_elapsed         (CutTest *test);
-
-const gchar *cut_test_get_attribute       (CutTest    *test,
-                                          const gchar *name);
-void         cut_test_set_attribute       (CutTest    *test,
-                                          const gchar *name,
-                                          const gchar *value);
-const GHashTable *cut_test_get_attributes (CutTest    *test);
+void         cut_test_stop_timer          (CutTest     *test);        
+const gchar *cut_test_get_name            (CutTest     *test);
+void         cut_test_set_name            (CutTest     *test,
+                                           const gchar *name);
+const gchar *cut_test_get_description     (CutTest     *test);
+gdouble      cut_test_get_elapsed         (CutTest     *test);
+const gchar *cut_test_get_attribute       (CutTest     *test,
+                                           const gchar *name);
+void         cut_test_set_attribute       (CutTest     *test,
+                                           const gchar *name,
+                                           const gchar *value);
+const GHashTable *cut_test_get_attributes (CutTest     *test);
 
 G_END_DECLS
 
