@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -206,12 +204,6 @@ CUT_MODULE_IMPL_INSTANTIATE (const gchar *first_property, va_list var_args)
     return g_object_new_valist(CUT_TYPE_REPORT_FACTORY_XML, first_property, var_args);
 }
 
-G_MODULE_EXPORT gchar *
-CUT_MODULE_IMPL_GET_LOG_DOMAIN (void)
-{
-    return g_strdup(G_LOG_DOMAIN);
-}
-
 static void
 set_option_group (CutModuleFactory *factory, GOptionContext *context)
 {
