@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -33,6 +31,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <cutter/cut-module-impl.h>
+#include <cutter/cut-listener.h>
 #include <cutter/cut-ui.h>
 #include <cutter/cut-runner.h>
 #include <cutter/cut-test-result.h>
@@ -53,7 +52,7 @@ typedef struct _CutUIGtkClass CutUIGtkClass;
 
 struct _CutUIGtk
 {
-    CutUI     object;
+    GObject        object;
 
     GtkWidget     *window;
     GtkProgressBar *progress_bar;
@@ -80,7 +79,7 @@ struct _CutUIGtk
 
 struct _CutUIGtkClass
 {
-    CutUIClass parent_class;
+    GObjectClass parent_class;
 };
 
 enum
@@ -103,7 +102,7 @@ enum
 };
 
 static GType cut_type_ui_gtk = 0;
-static CutUIClass *parent_class;
+static GObjectClass *parent_class;
 
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
@@ -114,30 +113,28 @@ static void get_property   (GObject         *object,
                             guint            prop_id,
                             GValue          *value,
                             GParamSpec      *pspec);
-static void attach_to_runner   (CutListener *listener,
-                                CutRunner   *runner);
-static void detach_from_runner (CutListener *listener,
-                                CutRunner   *runner);
+
+static void     attach_to_runner   (CutListener *listener,
+                                    CutRunner   *runner);
+static void     detach_from_runner (CutListener *listener,
+                                    CutRunner   *runner);
+static gboolean run                (CutUI       *ui,
+                                    CutRunner   *runner);
 
 static gboolean idle_cb_run_test (gpointer data);
 
 static void
-class_init (CutUIClass *klass)
+class_init (CutUIGtkClass *klass)
 {
     GObjectClass *gobject_class;
-    CutListenerClass *listener_class;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
-    listener_class = CUT_LISTENER_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
-
-    listener_class->attach_to_runner   = attach_to_runner;
-    listener_class->detach_from_runner = detach_from_runner;
 }
 
 static void
@@ -380,6 +377,19 @@ init (CutUIGtk *ui)
     setup_window(ui);
 }
 
+static void
+listener_init (CutListenerClass *listener)
+{
+    listener->attach_to_runner   = attach_to_runner;
+    listener->detach_from_runner = detach_from_runner;
+}
+
+static void
+ui_init (CutUIClass *ui)
+{
+    ui->run = run;
+}
+
 static void
 register_type (GTypeModule *type_module)
 {
@@ -396,10 +406,34 @@ register_type (GTypeModule *type_module)
             (GInstanceInitFunc) init,
         };
 
+	static const GInterfaceInfo ui_info =
+	    {
+            (GInterfaceInitFunc) ui_init,
+            NULL,
+            NULL
+        };
+
+	static const GInterfaceInfo listener_info =
+	    {
+            (GInterfaceInitFunc) listener_init,
+            NULL,
+            NULL
+        };
+
     cut_type_ui_gtk = g_type_module_register_type(type_module,
-                                                  CUT_TYPE_UI,
+                                                  G_TYPE_OBJECT,
                                                   "CutUIGtk",
                                                   &info, 0);
+
+    g_type_module_add_interface(type_module,
+                                cut_type_ui_gtk,
+                                CUT_TYPE_UI,
+                                &ui_info);
+
+    g_type_module_add_interface(type_module,
+                                cut_type_ui_gtk,
+                                CUT_TYPE_LISTENER,
+                                &listener_info);
 }
 
 G_MODULE_EXPORT GList *
@@ -427,12 +461,6 @@ CUT_MODULE_IMPL_INSTANTIATE (const gchar *first_property, va_list var_args)
     return g_object_new_valist(CUT_TYPE_UI_GTK, first_property, var_args);
 }
 
-G_MODULE_EXPORT gchar *
-CUT_MODULE_IMPL_GET_LOG_DOMAIN (void)
-{
-    return g_strdup(G_LOG_DOMAIN);
-}
-
 static void
 dispose (GObject *object)
 {
@@ -507,6 +535,9 @@ status_to_color (CutTestResultStatus status, gboolean only_if_not_success)
       case CUT_TEST_RESULT_NOTIFICATION:
         color = "light blue";
         break;
+      case CUT_TEST_RESULT_OMISSION:
+        color = "blue";
+        break;
       case CUT_TEST_RESULT_PENDING:
         color = "yellow";
         break;
@@ -516,6 +547,8 @@ status_to_color (CutTestResultStatus status, gboolean only_if_not_success)
       case CUT_TEST_RESULT_ERROR:
         color = "purple";
         break;
+      case CUT_TEST_RESULT_INVALID:
+        break;
     }
 
     return color;
@@ -534,6 +567,9 @@ get_status_icon (GtkTreeView *tree_view, CutTestResultStatus status)
       case CUT_TEST_RESULT_NOTIFICATION:
         stock_id = GTK_STOCK_DIALOG_WARNING;
         break;
+      case CUT_TEST_RESULT_OMISSION:
+        stock_id = GTK_STOCK_DIALOG_ERROR;
+        break;
       case CUT_TEST_RESULT_PENDING:
         stock_id = GTK_STOCK_DIALOG_ERROR;
         break;
@@ -543,6 +579,9 @@ get_status_icon (GtkTreeView *tree_view, CutTestResultStatus status)
       case CUT_TEST_RESULT_ERROR:
         stock_id = GTK_STOCK_CANCEL;
         break;
+      case CUT_TEST_RESULT_INVALID:
+        stock_id = GTK_STOCK_INFO;
+        break;
     }
     icon = gtk_widget_render_icon(GTK_WIDGET(tree_view),
                                   stock_id, GTK_ICON_SIZE_MENU,
@@ -555,7 +594,7 @@ static gchar *
 generate_summary_message (CutRunner *runner)
 {
     guint n_tests, n_assertions, n_failures, n_errors;
-    guint n_pendings, n_notifications;
+    guint n_pendings, n_notifications, n_omissions;
 
     n_tests = cut_runner_get_n_tests(runner);
     n_assertions = cut_runner_get_n_assertions(runner);
@@ -563,18 +602,20 @@ generate_summary_message (CutRunner *runner)
     n_errors = cut_runner_get_n_errors(runner);
     n_pendings = cut_runner_get_n_pendings(runner);
     n_notifications = cut_runner_get_n_notifications(runner);
+    n_omissions = cut_runner_get_n_omissions(runner);
 
     return g_strdup_printf(_("%d test(s), %d assertion(s), %d failure(s), "
-                             "%d error(s), %d pending(s), %d notification(s)"),
+                             "%d error(s), %d pending(s), %d omission(s), "
+                             "%d notification(s)"),
                            n_tests, n_assertions, n_failures, n_errors,
-                           n_pendings, n_notifications);
+                           n_pendings, n_omissions, n_notifications);
 }
 
 static gchar *
 generate_short_summary_message (CutRunner *runner)
 {
     guint n_tests, n_assertions, n_failures, n_errors;
-    guint n_pendings, n_notifications;
+    guint n_pendings, n_notifications, n_omissions;
 
     n_tests = cut_runner_get_n_tests(runner);
     n_assertions = cut_runner_get_n_assertions(runner);
@@ -582,10 +623,11 @@ generate_short_summary_message (CutRunner *runner)
     n_errors = cut_runner_get_n_errors(runner);
     n_pendings = cut_runner_get_n_pendings(runner);
     n_notifications = cut_runner_get_n_notifications(runner);
+    n_omissions = cut_runner_get_n_omissions(runner);
 
-    return g_strdup_printf(_("%dT:%dA:%dF:%d:E:%dP:%dN"),
+    return g_strdup_printf(_("%dT:%dA:%dF:%d:E:%dP:%dO:%dN"),
                            n_tests, n_assertions, n_failures, n_errors,
-                           n_pendings, n_notifications);
+                           n_pendings, n_omissions, n_notifications);
 }
 
 static gboolean
@@ -1126,6 +1168,18 @@ cb_notification_test (CutTest *test, CutTestContext *context,
     idle_add_append_test_result_row(info, result);
 }
 
+static void
+cb_omission_test (CutTest *test, CutTestContext *context,
+                  CutTestResult *result, gpointer data)
+{
+    TestRowInfo *info = data;
+
+    update_status(info, CUT_TEST_RESULT_OMISSION);
+
+    g_idle_add(idle_cb_update_test_row_status, data);
+    idle_add_append_test_result_row(info, result);
+}
+
 static gboolean
 idle_cb_push_running_test_message (gpointer data)
 {
@@ -1185,6 +1239,7 @@ cb_complete_test (CutTest *test, gpointer data)
     DISCONNECT(error);
     DISCONNECT(pending);
     DISCONNECT(notification);
+    DISCONNECT(omission);
     DISCONNECT(complete);
 #undef DISCONNECT
 }
@@ -1215,6 +1270,7 @@ cb_start_test (CutTestCase *test_case, CutTest *test,
     CONNECT(error);
     CONNECT(pending);
     CONNECT(notification);
+    CONNECT(omission);
     CONNECT(complete);
 #undef CONNECT
 }
@@ -1397,8 +1453,7 @@ run_test_thread_func (gpointer data)
     ui->n_tests = 0;
     ui->n_completed_tests = 0;
     ui->status = CUT_TEST_RESULT_SUCCESS;
-    cut_test_suite_run(ui->test_suite, runner);
-    disconnect_from_runner(ui, runner);
+    cut_runner_run(runner);
 
     g_object_unref(runner);
 
@@ -1411,7 +1466,6 @@ idle_cb_run_test (gpointer data)
     CutUIGtk *ui = data;
 
     gtk_tree_store_clear(ui->logs);
-    connect_to_runner(ui, ui->runner);
     g_thread_create(run_test_thread_func, ui, TRUE, NULL);
 
     return FALSE;
@@ -1421,13 +1475,7 @@ static void
 attach_to_runner (CutListener *listener,
                   CutRunner   *runner)
 {
-    CutUIGtk *gtk_ui = CUT_UI_GTK(listener);
-
-    gtk_ui->test_suite = g_object_ref(cut_runner_get_test_suite(runner));
-    gtk_ui->runner = g_object_ref(runner);
-    gtk_widget_show_all(gtk_ui->window);
-    g_idle_add(idle_cb_run_test, gtk_ui);
-    gtk_main();
+    connect_to_runner(CUT_UI_GTK(listener), runner);
 }
 
 static void
@@ -1437,6 +1485,22 @@ detach_from_runner (CutListener *listener,
     disconnect_from_runner(CUT_UI_GTK(listener), runner);
 }
 
+static gboolean
+run (CutUI *ui, CutRunner *runner)
+{
+    CutUIGtk *gtk_ui = CUT_UI_GTK(ui);
+    gboolean success = FALSE;
+
+    g_object_set(runner, "is_multi_thread", TRUE, NULL);
+    gtk_ui->test_suite = g_object_ref(cut_runner_get_test_suite(runner));
+    gtk_ui->runner = g_object_ref(runner);
+    gtk_widget_show_all(gtk_ui->window);
+    g_idle_add(idle_cb_run_test, gtk_ui);
+    gtk_main();
+
+    return success;
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
