@@ -7,9 +7,9 @@ if test x"$NO_MAKE" != x"yes"; then
 fi
 
 export CUT_UI_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
+export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
 export CUT_REPORT_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
 export CUT_REPORT_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
-export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
 
 CUTTER=$BASE_DIR/../../cutter/cutter
 if test x"$CUTTER_DEBUG" = x"yes"; then
@@ -18,7 +18,5 @@ fi
 CUTTER_ARGS="-s $BASE_DIR"
 if test x"$USE_GTK" = x"yes"; then
     CUTTER_ARGS="-u gtk $CUTTER_ARGS"
-else
-    CUTTER_ARGS="--color=auto $CUTTER_ARGS"
 fi
 $CUTTER $CUTTER_ARGS "$@" $BASE_DIR
