@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include "cutter.h"
 #include "cut-test.h"
 #include "cut-test-result.h"
@@ -5,8 +9,14 @@
 #include "cut-runner.h"
 #include "cuttest-assertions.h"
 
+#include <glib/gstdio.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
 void test_equal_int(void);
 void test_equal_string(void);
+void test_equal_string_with_diff(void);
 void test_equal_double(void);
 void test_operator(void);
 void test_equal_string_array (void);
@@ -25,9 +35,11 @@ void test_assert_equal_function (void);
 void test_failure_from_nested_function (void);
 void test_assert_errno (void);
 void test_omit (void);
+void test_file_exist (void);
 
 static gboolean need_cleanup;
 static gboolean compare_function_is_called;
+static gchar *tmp_file_name;
 
 static CutTest *test_object;
 static CutRunner *runner;
@@ -118,6 +130,7 @@ setup (void)
 {
     need_cleanup = FALSE;
     compare_function_is_called = FALSE;
+    tmp_file_name = NULL;
     test_object = NULL;
     runner = NULL;
     test_context = NULL;
@@ -127,6 +140,11 @@ setup (void)
 void
 teardown (void)
 {
+    if (tmp_file_name) {
+        g_remove(tmp_file_name);
+        g_free(tmp_file_name);
+    }
+
     if (!need_cleanup)
         return;
 
@@ -155,6 +173,36 @@ test_equal_string (void)
     cut_assert_equal_string("a", "a");
 }
 
+static void
+equal_string_with_diff (void)
+{
+    cut_assert_equal_string("abc def ghi jkl",
+                            "abc DEF ghi jkl");
+}
+
+void
+test_equal_string_with_diff (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("assert-equal-string-with-diff",
+                        equal_string_with_diff);
+    g_signal_connect(test, "failure", G_CALLBACK(cb_collect_result),
+                     &test_result);
+    cut_assert(!run(test));
+    cut_assert_test_result_summary(runner, 1, 0, 1, 0, 0, 0, 0);
+    cut_assert_equal_string("<\"abc def ghi jkl\" == \"abc DEF ghi jkl\">\n"
+                            "expected: <abc def ghi jkl>\n"
+                            " but was: <abc DEF ghi jkl>\n"
+                            "\n"
+                            "diff:\n"
+                            "- abc def ghi jkl\n"
+                            "?     ^^^\n"
+                            "+ abc DEF ghi jkl\n"
+                            "?     ^^^",
+                            cut_test_result_get_system_message(test_result));
+}
+
 void
 test_equal_double (void)
 {
@@ -339,10 +387,7 @@ test_assert_message_with_format_string (void)
                          cut_test_result_get_status(test_result));
     cut_assert_equal_string("<\"%s\" == \"%d\">\n"
                             "expected: <%s>\n"
-                            " but was: <%d>\n"
-                            "diff:\n"
-                            "- %s\n"
-                            "+ %d",
+                            " but was: <%d>",
                             cut_test_result_get_system_message(test_result));
     cut_assert_equal_string("expected and actual have format string",
                             cut_test_result_get_user_message(test_result));
@@ -402,7 +447,7 @@ test_failure_from_nested_function (void)
 }
 
 static void
-null_string_assertions ()
+null_string_assertions (void)
 {
     cut_assert_null_string(NULL);
     cut_assert_null_string("");
@@ -419,7 +464,7 @@ test_null_string (void)
 }
 
 static void
-equal_string_with_free_assertions ()
+equal_string_with_free_assertions (void)
 {
     cut_assert_equal_string_with_free(NULL, NULL);
     cut_assert_equal_string_with_free("", g_strdup(""));
@@ -476,6 +521,36 @@ test_omit (void)
     cut_assert_test_result_summary(runner, 1, 1, 0, 0, 0, 0, 1);
 }
 
+static void
+file_exist_test (void)
+{
+    gint fd;
+    GError *error = NULL;
+
+    fd = g_file_open_tmp(NULL, &tmp_file_name, &error);
+    if (fd == -1) {
+        const gchar *message;
+        message = cut_take_string(g_strdup(error->message));
+        g_error_free(error);
+        cut_error("can't create temporary file: %s", message);
+    }
+    close(fd);
+
+    cut_assert_file_exist(tmp_file_name);
+    g_remove(tmp_file_name);
+    cut_assert_file_exist(tmp_file_name);
+}
+
+void
+test_file_exist (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("file-exist-test", file_exist_test);
+    cut_assert(!run(test));
+    cut_assert_test_result_summary(runner, 1, 1, 1, 0, 0, 0, 0);
+}
+
 
 /*
 vi:nowrap:ai:expandtab:sw=4
