@@ -4,7 +4,8 @@
 #include "cuttest-utils.h"
 
 void test_load_function (void);
-void test_load_initialize_and_finalize_function (void);
+void test_load_startup_and_shutdown_function (void);
+void test_fail_to_load (void);
 
 static CutLoader *test_loader;
 static CutTestCase *test_case;
@@ -38,7 +39,7 @@ teardown (void)
         g_strfreev(test_names);
 }
 
-static const gchar *expected_functions[] = {
+static gchar *expected_functions[] = {
     "test_abcdefghijklmnopqratuvwzyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789",
     "test_dummy_function1",
     "test_dummy_function2",
@@ -61,7 +62,7 @@ test_load_function (void)
 {
     CutTestContainer *container;
     GList *tests, *list;
-    const gchar *target_test_names[] = {"/.*/", NULL};
+    gchar *target_test_names[] = {"/.*/", NULL};
     gint i;
 
     test_case = cut_loader_load_test_case(test_loader);
@@ -89,20 +90,39 @@ test_load_function (void)
 }
 
 void
-test_load_initialize_and_finalize_function (void)
+test_load_startup_and_shutdown_function (void)
 {
-    CutInitializeFunction initialize_function = NULL;
-    CutFinalizeFunction finalize_function = NULL;
+    CutStartupFunction startup_function = NULL;
+    CutShutdownFunction shutdown_function = NULL;
 
     test_case = cut_loader_load_test_case(test_loader);
     cut_assert(test_case);
 
     g_object_get(G_OBJECT(test_case),
-                 "initialize-function", &initialize_function,
-                 "finalize-function", &finalize_function,
+                 "startup-function", &startup_function,
+                 "shutdown-function", &shutdown_function,
                  NULL);
-    cut_assert(initialize_function);
-    cut_assert(finalize_function);
+    cut_assert(startup_function);
+    cut_assert(shutdown_function);
+}
+
+void
+test_fail_to_load (void)
+{
+    CutLoader *loader;
+    gchar *test_path;
+
+    test_path = g_build_filename(cuttest_get_base_dir(),
+                                 "module_test_dir",
+                                 ".libs",
+                                 "cannot_load_module.so",
+                                 NULL);
+    loader = cut_loader_new(test_path);
+    g_free(test_path);
+
+    cut_assert(loader);
+    cut_assert_null(cut_loader_load_test_case(loader));
+    g_object_unref(loader);
 }
 
 /*
