@@ -22,6 +22,7 @@ void test_error_signal(void);
 void test_pending_signal(void);
 void test_notification_signal(void);
 void test_complete_signal(void);
+void test_omission_signal(void);
 
 static CutTestCase *test_object;
 static CutRunner *runner;
@@ -80,6 +81,12 @@ dummy_notification_test (void)
     cut_notify("Notify!!!");
 }
 
+static void
+dummy_omission_test (void)
+{
+    cut_omit("Omit!!!");
+}
+
 static void
 dummy_setup_function (void)
 {
@@ -97,7 +104,7 @@ dummy_teardown_function (void)
 void
 setup (void)
 {
-    const gchar *test_names[] = {"/.*/", NULL};
+    gchar *test_names[] = {"/.*/", NULL};
 
     set_error_on_setup = FALSE;
 
@@ -167,8 +174,8 @@ test_teardown (void)
 void
 test_test_case_count (void)
 {
-    const gchar *test_names[] = {"/.*/", NULL};
-    cut_assert_equal_int(0, cut_test_case_get_n_tests(test_object, NULL));
+    gchar *test_names[] = {"/.*/", NULL};
+    cut_assert_equal_int(3, cut_test_case_get_n_tests(test_object, NULL));
     cut_assert_equal_int(3, cut_test_case_get_n_tests(test_object, test_names));
 }
 
@@ -212,7 +219,7 @@ test_run_tests_with_regex (void)
 void
 test_run_with_name_filter (void)
 {
-    const gchar *names[] = {"dummy_test_1", "run_test_function", NULL};
+    gchar *names[] = {"dummy_test_1", "run_test_function", NULL};
 
     cut_assert(cut_test_case_run_with_filter(test_object, runner, names));
     cut_assert_equal_int(1, n_run_dummy_run_test_function);
@@ -223,7 +230,7 @@ test_run_with_name_filter (void)
 void
 test_run_with_regex_filter (void)
 {
-    const gchar *regex[] = {"/dummy/", NULL};
+    gchar *regex[] = {"/dummy/", NULL};
 
     cut_assert(cut_test_case_run_with_filter(test_object, runner, regex));
     cut_assert_equal_int(0, n_run_dummy_run_test_function);
@@ -234,7 +241,7 @@ test_run_with_regex_filter (void)
 void
 test_run_with_name_and_regex_filter (void)
 {
-    const gchar *name_and_regex[] = {"/dummy/", "run_test_function", NULL};
+    gchar *name_and_regex[] = {"/dummy/", "run_test_function", NULL};
 
     cut_assert(cut_test_case_run_with_filter(test_object, runner,
                                              name_and_regex));
@@ -346,6 +353,21 @@ test_complete_signal (void)
     cut_assert_equal_int(3, n_complete_tests);
 }
 
+void
+test_omission_signal (void)
+{
+    gint n_omissions = 0;
+    g_signal_connect(test_object, "omission",
+                     G_CALLBACK(cb_count_status), &n_omissions);
+    cuttest_add_test(test_object, "dummy_omission_test",
+                     dummy_omission_test);
+    cut_assert(cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_omissions);
+    cut_assert_equal_int(1, n_omissions);
+}
+
 /*
 vi:nowrap:ai:expandtab:sw=4
 */
