@@ -3,9 +3,11 @@
 #include <cutter/cut-test-case.h>
 #include <cutter/cut-test-suite.h>
 #include <cutter/cut-loader.h>
+#include <signal.h>
 
 #include "cuttest-utils.h"
 
+void test_run (void);
 void test_run_test_case (void);
 void test_run_test_case_with_regex (void);
 void test_run_test (void);
@@ -16,6 +18,7 @@ void test_run_test_in_test_case_with_regex (void);
 void test_run_test_with_regex_in_test_case_with_regex (void);
 void test_run_test_in_test_case_with_null (void);
 void test_run_test_with_filter_with_null (void);
+void test_crashed_signal (void);
 
 static CutRunner *runner;
 static CutTestSuite *test_object;
@@ -29,6 +32,7 @@ static gint n_run_bummy_run_test_function = 0;
 static gint n_run_bummy_test_function1 = 0;
 static gint n_run_bummy_test_function2 = 0;
 
+static gint n_crashed_signal = 0;
 
 static void
 dummy_test_function1 (void)
@@ -70,6 +74,18 @@ bummy_run_test_function (void)
     n_run_bummy_run_test_function++;
 }
 
+static void
+dummy_crashed_function (void)
+{
+    raise(SIGSEGV);
+}
+
+static void
+cb_crashed_signal (CutTest *test, gpointer data)
+{
+    n_crashed_signal++;
+}
+
 void
 setup (void)
 {
@@ -82,6 +98,7 @@ setup (void)
     n_run_bummy_test_function1 = 0;
     n_run_bummy_test_function2 = 0;
     n_run_bummy_run_test_function = 0;
+    n_crashed_signal = 0;
 
     runner = cut_runner_new();
 
@@ -129,7 +146,7 @@ teardown (void)
 }
 
 static gboolean
-run_test_case (const gchar *test_case_name)
+run_test_case (gchar *test_case_name)
 {
     return cut_test_suite_run_test_in_test_case(test_object,
                                                 runner,
@@ -138,13 +155,13 @@ run_test_case (const gchar *test_case_name)
 }
 
 static gboolean
-run_test (const gchar *test_name)
+run_test (gchar *test_name)
 {
     return cut_test_suite_run_test(test_object, runner, test_name);
 }
 
 static gboolean
-run_test_in_test_case (const gchar *test_name, const gchar *test_case_name)
+run_test_in_test_case (gchar *test_name, gchar *test_case_name)
 {
     return cut_test_suite_run_test_in_test_case(test_object,
                                                 runner,
@@ -153,7 +170,7 @@ run_test_in_test_case (const gchar *test_name, const gchar *test_case_name)
 }
 
 static gboolean
-run_test_with_filter (const gchar **test_case_names, const gchar **test_names)
+run_test_with_filter (gchar **test_case_names, gchar **test_names)
 {
     return cut_test_suite_run_with_filter(test_object,
                                           runner,
@@ -161,10 +178,23 @@ run_test_with_filter (const gchar **test_case_names, const gchar **test_names)
                                           test_names);
 }
 
+void
+test_run (void)
+{
+    cut_assert(cut_test_suite_run(test_object, runner));
+    cut_assert_equal_int(1, n_run_dummy_test_function1);
+    cut_assert_equal_int(1, n_run_dummy_test_function2);
+    cut_assert_equal_int(1, n_run_dummy_run_test_function);
+    cut_assert_equal_int(1, n_run_bummy_test_function1);
+    cut_assert_equal_int(1, n_run_bummy_test_function2);
+    cut_assert_equal_int(1, n_run_bummy_run_test_function);
+}
+
 void
 test_run_test_case (void)
 {
-    cut_assert(run_test_case("dummy_test_case"));
+    cut_assert(cut_test_suite_run_test_case(test_object, runner,
+                                            "dummy_test_case"));
     cut_assert_equal_int(1, n_run_dummy_test_function1);
     cut_assert_equal_int(1, n_run_dummy_test_function2);
     cut_assert_equal_int(1, n_run_dummy_run_test_function);
@@ -261,27 +291,55 @@ void
 test_run_test_in_test_case_with_null (void)
 {
     cut_assert(run_test(NULL));
-    cut_assert_equal_int(0, n_run_dummy_test_function1);
-    cut_assert_equal_int(0, n_run_dummy_test_function2);
-    cut_assert_equal_int(0, n_run_dummy_run_test_function);
-    cut_assert_equal_int(0, n_run_bummy_test_function1);
-    cut_assert_equal_int(0, n_run_bummy_test_function2);
-    cut_assert_equal_int(0, n_run_bummy_run_test_function);
+    cut_assert_equal_int(1, n_run_dummy_test_function1);
+    cut_assert_equal_int(1, n_run_dummy_test_function2);
+    cut_assert_equal_int(1, n_run_dummy_run_test_function);
+    cut_assert_equal_int(1, n_run_bummy_test_function1);
+    cut_assert_equal_int(1, n_run_bummy_test_function2);
+    cut_assert_equal_int(1, n_run_bummy_run_test_function);
 }
 
 void
 test_run_test_with_filter_with_null (void)
 {
     cut_assert(run_test_with_filter(NULL, NULL));
-    cut_assert_equal_int(0, n_run_dummy_test_function1);
-    cut_assert_equal_int(0, n_run_dummy_test_function2);
-    cut_assert_equal_int(0, n_run_dummy_run_test_function);
-    cut_assert_equal_int(0, n_run_bummy_test_function1);
-    cut_assert_equal_int(0, n_run_bummy_test_function2);
-    cut_assert_equal_int(0, n_run_bummy_run_test_function);
+    cut_assert_equal_int(1, n_run_dummy_test_function1);
+    cut_assert_equal_int(1, n_run_dummy_test_function2);
+    cut_assert_equal_int(1, n_run_dummy_run_test_function);
+    cut_assert_equal_int(1, n_run_bummy_test_function1);
+    cut_assert_equal_int(1, n_run_bummy_test_function2);
+    cut_assert_equal_int(1, n_run_bummy_run_test_function);
+}
+
+static void
+segv_handler (int signum)
+{
+    return;
+}
+
+void
+test_crashed_signal (void)
+{
+    CutTestCase *test_case;
+
+    test_case = cut_test_case_new("crash_test_case", NULL, NULL,
+                                  get_current_test_context,
+                                  set_current_test_context,
+                                  NULL, NULL);
+    cuttest_add_test(test_case, "crash_test", dummy_crashed_function);
+    cut_test_suite_add_test_case(test_object, test_case);
+    g_object_unref(test_case);
+
+    signal(SIGSEGV, segv_handler);
+    g_signal_connect(test_object, "crashed", G_CALLBACK(cb_crashed_signal), NULL);
+    cut_assert(!run_test_in_test_case("crash_test", "crash_test_case"));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_crashed_signal),
+                                         NULL);
+    cut_assert_equal_int(1, n_crashed_signal);
 }
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
 
